@@ -1,5 +1,5 @@
 /*
- * Copyright 2005 - 2012  Zarafa B.V.
+ * Copyright 2005 - 2013  Zarafa B.V.
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3, 
@@ -443,9 +443,4 @@ var olOwnTask		= 3;	// Task owned
 var olTaskNotDelegated			= 0;
 var olTaskDelegationUnknown		= 1;	// After sending req
 var olTaskDelegationAccepted	= 2;	// After receiving accept
-var olTaskDelegationDeclined	= 3;	// After receiving decline
-
-// action flavors for OP_FORWARD
-var FWD_PRESERVE_SENDER			= 1;	// Preserves the sender information and indicates the message was autoforwarded.
-var FWD_DO_NOT_MUNGE_MSG		= 2;	// Forwards the message without making any changes to the message.
-var FWD_AS_ATTACHMENT			= 4;	// Makes the message an attachment to the forwarded message.
\ No newline at end of file
+var olTaskDelegationDeclined	= 3;	// After receiving decline
\ No newline at end of file
