@@ -1,5 +1,5 @@
 /*
- * Copyright 2005 - 2012  Zarafa B.V.
+ * Copyright 2005 - 2013  Zarafa B.V.
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3, 
@@ -293,10 +293,12 @@ appointmentlistmodule.prototype.getAppointmentProps = function(starttime, endtim
 	else
 		props["label"] = 0;
 
-	if(busystatus)
+	// busystatus can be '0' i.e fbFree
+	if (busystatus !== undefined && busystatus !== null) {
 		props["busystatus"] = busystatus;
-	else
-		props["busystatus"] = 2;
+	} else {
+		props["busystatus"] = fbBusy;
+	}
 
 	props["startdate"] = starttime;
 	props["commonstart"] = starttime;
@@ -334,6 +336,16 @@ appointmentlistmodule.prototype.getAppointmentProps = function(starttime, endtim
 
 appointmentlistmodule.prototype.createAppointment = function(starttime, endtime, subject, location, label, busystatus, remindertime, alldayevent)
 {
+	// If selection is from 00:00 to 24:00 then also appointment is allday event
+	var startDate = new Date(starttime*1000);
+	var endDate = new Date(endtime*1000);
+	if ((startDate.strftime("%H:%M:%S") == "00:00:00") &&(endDate.strftime("%H:%M:%S") == "00:00:00")) {
+		alldayevent = true;
+	}
+
+	// If appointment is an allday event then set busystatus to 'Free'
+	busystatus = alldayevent ? fbFree : busystatus;
+
 	this.save(this.getAppointmentProps(starttime, endtime, subject, location, label, busystatus, remindertime, alldayevent));
 }
 
