@@ -1,6 +1,6 @@
 <?php
 /*
- * Copyright 2005 - 2012  Zarafa B.V.
+ * Copyright 2005 - 2013  Zarafa B.V.
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3, 
@@ -50,7 +50,7 @@
 
 ?>
 <?php
-	require_once("mapi/class.baserecurrence.php");
+	require_once("class.baserecurrence.php");
 
 	class TaskRecurrence extends BaseRecurrence
 	{
@@ -334,7 +334,7 @@
 
 			// Update body of original message
 			$msgbody = mapi_message_openproperty($this->message, PR_BODY);
-			$msgbody = trim($this->windows1252_to_utf8($msgbody), "\0");
+			$msgbody = trim($msgbody, "\0");
 			$separator = "------------\r\n";
 
 			if (!empty($msgbody) && strrpos($msgbody, $separator) === false) {
@@ -444,22 +444,5 @@
 
 			return $result;
 		}
-
-		/**
-		* Convert from windows-1252 encoded string to UTF-8 string
-		*
-		* The same conversion rules as utf8_to_windows1252 apply.
-		*
-		* @param string $string the Windows-1252 string to convert
-		* @return string UTF-8 representation of the string
-		*/
-		function windows1252_to_utf8($string)
-		{
-			if (function_exists("iconv")){
-				return iconv("Windows-1252", "UTF-8//TRANSLIT", $string);
-			}else{
-				return utf8_encode($string); // no euro support here
-			}
-		}
 	}
 ?>
