@@ -1,6 +1,6 @@
 <?php
 /*
- * Copyright 2005 - 2012  Zarafa B.V.
+ * Copyright 2005 - 2013  Zarafa B.V.
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3, 
@@ -550,7 +550,7 @@
 				$store = $this->store;
 			} else {
 				$ab = mapi_openaddressbook($session);
-				if(!ab) return false;
+				if(!$ab) return false;
 				
 				$mailuser = mapi_ab_openentry($ab, $ownerentryid);
 				if(!$mailuser) return false;
@@ -969,25 +969,6 @@
 			return $body;
 		}
 
-		/**
-		* Convert from windows-1252 encoded string to UTF-8 string
-		*
-		* The same conversion rules as utf8_to_windows1252 apply.
-		*
-		* @see Conversion::utf8_to_windows1252()
-		*
-		* @param string $string the Windows-1252 string to convert
-		* @return string UTF-8 representation of the string
-		*/
-		function windows1252_to_utf8($string)
-		{
-			if (function_exists("iconv")){
-				return iconv("Windows-1252", "UTF-8//TRANSLIT", $string);
-			}else{
-				return utf8_encode($string); // no euro support here
-			}
-		}
-
 		/** Reclaims ownership of a decline task
 		 *
 		 * Deletes taskrequest properties and recipients from the task message.
